@@ -14,10 +14,9 @@ logger = logging.getLogger(__name__)
 
 
 class SHReaderBDO2019(SHReader):
-    """
-    Experimental binary format reader version >= 0.7
-    """
-    def read_data(self, estimator):
+    """Experimental binary format reader version >= 0.7"""
+
+    def read_data(self, estimator, nscale=1):
         logger.debug("Reading: " + self.filename)
 
         with open(self.filename, "rb") as f:
@@ -167,7 +166,16 @@ class SHReaderBDO2019(SHReader):
                 if not page.name:
                     page.name = str(page.dettyp)
 
-            estimator.file_format = 'bdo2019'
+            # apply basic normalization for pages with normalisation tag
+            for page in estimator.pages:
+                page_normalisation = getattr(page, 'page_normalized', None)
+                # see pymchelper/readers/shieldhit/binary_spec.py for details on the normalisation tags
+                # normalize the detectors such as dose or fluence (tagged as SH_POSTPROC_NORM or 2)
+                if page_normalisation == 2:
+                    page.data_raw /= np.float64(estimator.number_of_primaries)
+                    page.error_raw /= np.float64(estimator.number_of_primaries)
 
-            logger.debug("Done reading bdo file.")
-            return True
+        estimator.file_format = 'bdo2019'
+
+        logger.debug("Done reading bdo file.")
+        return True
