@@ -28,7 +28,8 @@ class Inspector:
                 if name not in {'data', 'data_raw', 'error', 'error_raw'}:
                     line = "\t{:24s}: '{:s}'".format(str(name), str(value))
                     print(line)
-            print("Data min: {:g}, max: {:g}".format(page.data_raw.min(), page.data_raw.max()))
+            print("Data min: {:g}, max: {:g}, mean: {:g}".format(
+                page.data_raw.min(), page.data_raw.max(), page.data_raw.mean()))
             print(75 * "-")
 
         if self.options.details:
